aboutsummaryrefslogtreecommitdiff
path: root/include/wlr/render.h
diff options
context:
space:
mode:
authornyorain <nyorain@gmail.com>2017-08-08 18:02:14 +0200
committernyorain <nyorain@gmail.com>2017-08-08 18:25:16 +0200
commite167f41fde7532ca453a9a70ad1e3f27d7177071 (patch)
treefb4f62dc4fcd4017db8695fc99a0e7ade8d6d80b /include/wlr/render.h
parentafd058b754e568728fbc7e2e34651dab9a8a827f (diff)
Rename wlr_surface -> wlr_texture; attach -> upload
Diffstat (limited to 'include/wlr/render.h')
-rw-r--r--include/wlr/render.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/include/wlr/render.h b/include/wlr/render.h
index 4de2432d..3dcc482c 100644
--- a/include/wlr/render.h
+++ b/include/wlr/render.h
@@ -4,30 +4,30 @@
#include <wayland-server-protocol.h>
#include <wlr/types/wlr_output.h>
-struct wlr_surface;
+struct wlr_texture;
struct wlr_renderer;
void wlr_renderer_begin(struct wlr_renderer *r, struct wlr_output *output);
void wlr_renderer_end(struct wlr_renderer *r);
/**
* Requests a surface handle from this renderer.
*/
-struct wlr_surface *wlr_render_surface_init(struct wlr_renderer *r);
+struct wlr_texture *wlr_render_texture_init(struct wlr_renderer *r);
/**
* Renders the requested surface using the provided matrix. A typical surface
* rendering goes like so:
*
* struct wlr_renderer *renderer;
- * struct wlr_surface *surface;
+ * struct wlr_texture *texture;
* float projection[16];
* float matrix[16];
- * wlr_surface_get_matrix(surface, &matrix, &projection, 123, 321);
- * wlr_render_with_matrix(renderer, surface, &matrix);
+ * wlr_texture_get_matrix(texture, &matrix, &projection, 123, 321);
+ * wlr_render_with_matrix(renderer, texture, &matrix);
*
* This will render the surface at <123, 321>.
*/
bool wlr_render_with_matrix(struct wlr_renderer *r,
- struct wlr_surface *surface, const float (*matrix)[16]);
+ struct wlr_texture *texture, const float (*matrix)[16]);
/**
* Renders a solid quad in the specified color.
*/
@@ -44,16 +44,16 @@ void wlr_render_colored_ellipse(struct wlr_renderer *r,
const enum wl_shm_format *wlr_renderer_get_formats(
struct wlr_renderer *r, size_t *len);
/**
- * Destroys this wlr_renderer. Surfaces must be destroyed separately.
+ * Destroys this wlr_renderer. Textures must be destroyed separately.
*/
void wlr_renderer_destroy(struct wlr_renderer *renderer);
-struct wlr_surface_impl;
-struct wlr_surface_state;
+struct wlr_texture_impl;
+struct wlr_texture_state;
-struct wlr_surface {
- struct wlr_surface_impl *impl;
- struct wlr_surface_state *state;
+struct wlr_texture {
+ struct wlr_texture_impl *impl;
+ struct wlr_texture_state *state;
bool valid;
uint32_t format;
int width, height;
@@ -62,32 +62,32 @@ struct wlr_surface {
};
/**
* Attaches a pixel buffer to this surface. The buffer may be discarded after
* calling this function.
*/
-bool wlr_surface_attach_pixels(struct wlr_surface *surf,
+bool wlr_texture_upload_pixels(struct wlr_texture *surf,
enum wl_shm_format format, int stride, int width, int height,
const unsigned char *pixels);
/**
* Attaches pixels from a wl_shm_buffer to this surface. The shm buffer may be
* invalidated after calling this function.
*/
-bool wlr_surface_attach_shm(struct wlr_surface *surf, uint32_t format,
+bool wlr_texture_upload_shm(struct wlr_texture *surf, uint32_t format,
struct wl_shm_buffer *shm);
/**
* Prepares a matrix with the appropriate scale for the given surface and
* multiplies it with the projection, producing a matrix that the shader can
* muptlipy vertex coordinates with to get final screen coordinates.
- *
+ *
* The projection matrix is assumed to be an orthographic projection of [0,
* width) and [0, height], and the x and y coordinates provided are used as
* such.
*/
-void wlr_surface_get_matrix(struct wlr_surface *surface,
+void wlr_texture_get_matrix(struct wlr_texture *texture,
float (*matrix)[16], const float (*projection)[16], int x, int y);
/**
- * Destroys this wlr_surface.
+ * Destroys this wlr_texture.
*/
-void wlr_surface_destroy(struct wlr_surface *tex);
+void wlr_texture_destroy(struct wlr_texture *texture);
#endif
@@ -4,30 +4,30 @@
void wlr_renderer_end(struct wlr_renderer *r);
/**
- * Requests a surface handle from this renderer.
+ * Requests a texture handle from this renderer.
*/
@@ -4,30 +4,30 @@
/**
- * Renders the requested surface using the provided matrix. A typical surface
+ * Renders the requested texture using the provided matrix. A typical texture
* rendering goes like so:
*
@@ -4,30 +4,30 @@
*
- * This will render the surface at <123, 321>.
+ * This will render the texture at <123, 321>.
*/
bool wlr_render_with_matrix(struct wlr_renderer *r,
@@ -62,32 +62,32 @@ struct wlr_surface {
};
/**
- * Attaches a pixel buffer to this surface. The buffer may be discarded after
+ * Uploads a pixel buffer to this texture. The buffer may be discarded after
* calling this function.
*/
@@ -62,32 +62,32 @@ struct wlr_surface {
const unsigned char *pixels);
/**
- * Attaches pixels from a wl_shm_buffer to this surface. The shm buffer may be
+ * Uploads pixels from a wl_shm_buffer to this texture. The shm buffer may be
* invalidated after calling this function.
*/
@@ -62,32 +62,32 @@ struct wlr_surface {
struct wl_shm_buffer *shm);
/**
- * Prepares a matrix with the appropriate scale for the given surface and
+ * Prepares a matrix with the appropriate scale for the given texture and
* multiplies it with the projection, producing a matrix that the shader can
* muptlipy vertex coordinates with to get final screen coordinates.